unquad.strategy.bootstrap.Bootstrap
===================================

.. currentmodule:: unquad.strategy.bootstrap

.. autoclass:: Bootstrap

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Bootstrap.__init__
      ~Bootstrap.fit_calibrate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Bootstrap.calibration_ids
   
   